@@ -584,7 +584,7 @@ class LivejAccount(Account, Service):
         return user
 
 
-    def refresh_friends_list(self):
+    def refresh_friends_list(self, callback):
         """
         Refresh list of current frinds and groups.
         
@@ -597,9 +597,9 @@ class LivejAccount(Account, Service):
                       #'includegroups': '1',
                       'includebdays': '1'
                      })
-
+        callback()
         result = self.exec_xmlrpc('getfriends', param)
-
+        callback()   
         #parse result from server
         self.friends_list = []
         old_friends = self.get_option('friends')
@@ -613,9 +613,10 @@ class LivejAccount(Account, Service):
                 old_friends.remove(username)
             except ValueError:
                 has_new = True
+            callback()
 
         '''
-        deleting posts of old friends from DB, we souldn't see their posts 
+        deleting posts of old friends from DB, we souldnt see their posts 
         in our friendlist
         '''
         for i in old_friends:
@@ -628,7 +629,7 @@ class LivejAccount(Account, Service):
         for i in friendofs:
             self.add_reader(self._parse_user(i))
         '''
-
+        callback()
         return has_new
 
 
@@ -696,7 +697,7 @@ class LivejAccount(Account, Service):
         callback()
 
         if 1 == result['new']:
-            new_friends = self.refresh_friends_list()
+            new_friends = self.refresh_friends_list(callback)
             callback()
             self._get_friends_posts(new_friends, callback)
 
