@@ -1,12 +1,7 @@
 #!/usr/bin/env python
-
-import sys
-sys.path.append("..")
-sys.path.append("../ldm")
-sys.path.append("../services")
-
-from Account import Account
-from Dispatcher import dispatcher
+from ldm.SqlDriver import sql_driver
+from ldm.Account import Account
+from services.Dispatcher import dispatcher
 
 __author__ = "Mezhenin Artoym <mezhenin@cs.karelia.ru>"
 __version__ = "$Revision: 1 $"
