@@ -29,7 +29,7 @@ class HomePage(MainWindow):
     @version  1.0   
     @author  Zaiceva Diana <zaiceva@cs.karelia.ru>   
     """
-    def __init__(self, parent=None):
+    def __init__(self, def_account, parent=None):
         """
         Initialization for HomeWindow   
         @param parent (widget) 
@@ -38,12 +38,13 @@ class HomePage(MainWindow):
         if not main_prof.accounts:
             from StartPage import start_page
         else:    
-            super(HomePage, self).__init__(parent = None)
+            super(HomePage, self).__init__(parent)
             self.parent = parent
             self.centr_widg = QtGui.QWidget(self) 
             self.account = []
             self.vboxmain = QtGui.QVBoxLayout()
-            self.vboxmain.addLayout(self.create_info_group())
+            self.vboxmain.addStretch(1)
+            self.vboxmain.addLayout(self.create_info_group(def_account))
             self.vboxmain.addSpacing(20)
             self.vboxmain.addLayout(self.create_push_button_group(), 2)
             self.vboxmain.addSpacing(20)
@@ -88,22 +89,26 @@ class HomePage(MainWindow):
         @return info = string with information
         """
 
-        def_acc = main_prof.def_account
-
+        #def_acc = main_prof.def_account
+        print def_acc
         info = self.tr("<h2>Personal info:</h2><br>")
         if def_acc.nick:
+            print def_acc.nick
             info = info + self.tr("<div>Nick: <b>")\
-            + QtCore.QString(unicode(def_acc.nick)) + self.tr("</b></div><br>")
+            + QtCore.QString(def_acc.nick) + self.tr("</b></div>")
         if def_acc.date_of_birth:
+            print def_acc.date_of_birth
             info = info + self.tr("<div>Birthday: <b>")\
-            + QtCore.QString(unicode(def_acc.date_of_birth)) + self.tr("</b></div><br>")
+            + QtCore.QString(def_acc.date_of_birth) + self.tr("</b></div>")
         if def_acc.city:
+            print def_acc.city
             info = info + self.tr("<div>City: <b>")\
-            + QtCore.QString(unicode(def_acc.city)) + self.tr("</b></div>")
+            + QtCore.QString(def_acc.city) + self.tr("</b></div>")
         if def_acc.get_name():
+            print def_acc.get_name()
             info = info + self.tr("<div>Blog service: <b>")\
-            + QtCore.QString(unicode(def_acc.get_name())) + self.tr("<b><br></div><br>")
-            return info
+            + QtCore.QString(def_acc.get_name()) + self.tr("<b><br></div>")
+        return info
 
     def reload_list(self, number):
         '''        
@@ -124,7 +129,7 @@ class HomePage(MainWindow):
 
 
 
-    def create_info_group(self):
+    def create_info_group(self, def_acc):
         """
         draw information about user
         @param
@@ -132,7 +137,7 @@ class HomePage(MainWindow):
         """
         hbox = QtGui.QHBoxLayout()
         vbox1 = QtGui.QVBoxLayout()
-        def_acc = main_prof.def_account
+        #def_acc = main_prof.def_account
 
         #label with personal information
         self.info_label = QtGui.QLabel(self.fill_user_info(def_acc), self.centr_widg)
@@ -152,7 +157,8 @@ class HomePage(MainWindow):
             self.image_label.setPixmap(QtGui.QPixmap.fromImage(QtGui.QImage("../data/en/no_photo_128.png")))
 
         vbox1.addWidget(self.image_label)
-        vbox1.addWidget(self.acc_combo_box)
+        if self.acc_combo_box:
+            vbox1.addWidget(self.acc_combo_box)
 
         hbox.addLayout(vbox1)
         hbox.addWidget(self.info_label)
@@ -168,15 +174,26 @@ class HomePage(MainWindow):
         add_post_button = QtGui.QPushButton(self.tr("&Add post"), self.centr_widg)
         my_post_button = QtGui.QPushButton(self.tr("&My posts"), self.centr_widg)
         friends_posts_btn = QtGui.QPushButton(self.tr("&Friends' posts"), self.centr_widg)
+        friends_list_btn = QtGui.QPushButton(self.tr("&Friends"), self.centr_widg)
 
+        
         add_post_button.setIcon(QtGui.QIcon(self.tr("../data/en/add_post.png")))
         my_post_button.setIcon(QtGui.QIcon(self.tr("../data/en/my_posts.png")))
         friends_posts_btn.setIcon(QtGui.QIcon(self.tr("../data/en/friends_posts.png")))
+        friends_list_btn.setIcon(QtGui.QIcon(self.tr("../data/en/friends.png")))
+
+
+        add_post_button.setIconSize(QtCore.QSize(32, 32))
+        my_post_button.setIconSize(QtCore.QSize(32, 32))
+        friends_posts_btn.setIconSize(QtCore.QSize(32, 32))
+        friends_list_btn.setIconSize(QtCore.QSize(32, 32))
+
 
         hbox = QtGui.QHBoxLayout()
         hbox.addWidget(add_post_button, -1, QtCore.Qt.AlignCenter)
         hbox.addWidget(my_post_button, -1, QtCore.Qt.AlignCenter)
         hbox.addWidget(friends_posts_btn, -1, QtCore.Qt.AlignCenter)
+        hbox.addWidget(friends_list_btn, -1, QtCore.Qt.AlignCenter)
 
         self.connect(add_post_button, QtCore.SIGNAL("clicked()"),
                      self.add_post)
@@ -184,6 +201,8 @@ class HomePage(MainWindow):
                      self.list_my_posts)
         self.connect(friends_posts_btn, QtCore.SIGNAL("clicked()"),
                      self.list_friends_posts)
+        self.connect(friends_list_btn, QtCore.SIGNAL("clicked()"),
+                     self.list_friends)
         return hbox
 
     def add_post(self):
@@ -213,3 +232,12 @@ class HomePage(MainWindow):
         """
         from ListFriendsPosts import ListFriendsPosts
         widg = ListFriendsPosts(self)
+
+    def list_friends(self):
+        """                                                                                                                                                 
+        handler for clicked "friends"                                                                                                                  
+        @param                                                                                                                                              
+        @return                                                                                                                                             
+        """
+        from ListFriends import ListFriends
+        widg = ListFriends(self)
