@@ -34,7 +34,12 @@ class ListFriendsPosts(ListMyPosts):
             except WarningExc, exc:
                 super(ListMyPosts, self).show_warning(exc)
 
-    def get_messages(self):
+    def get_messages(self, friend):
+        """
+        getting frinds posts
+        @param friend - in future, for getting friends posts of friend
+        @return list posts
+        """
         return main_prof.get_friends_posts(20)
 
     def create_toolbar(self):
