@@ -25,18 +25,19 @@ class ListMyPosts(MainWindow):
     @version  1.0
     @author  Zaiceva Diana <zaiceva@cs.karelia.ru>
     """
-    def __init__(self, parent):
+    def __init__(self, parent, friend = None):
         """ 
         initialization "list of posts" window
         @return
         """
+        self.friend = friend
         super(ListMyPosts,self).__init__(parent)
         self.centr_widg = QtGui.QWidget(self)
         self.create_actions()
         self.parent = parent
         toolbar = self.create_toolbar()
         self.hbox = QtGui.QHBoxLayout()
-        self.mes_list = self.list_posts()
+        self.mes_list = self.list_posts(friend)
         self.hbox.addWidget(toolbar)
         self.hbox.addSpacing(10)
         self.hbox.addWidget(self.mes_list)
@@ -44,14 +45,14 @@ class ListMyPosts(MainWindow):
         self.setCentralWidget(self.centr_widg)
         self.show()
 
-    def list_posts(self):
+    def list_posts(self, friend):
         """
         fill list of posts
         @param
         @return
         """
         list_widget = QtGui.QListWidget(self.centr_widg)
-        self.list = self.get_messages()
+        self.list = self.get_messages(friend)
         index = 0
 
         if len(self.list) == 0:
@@ -83,8 +84,6 @@ class ListMyPosts(MainWindow):
                 title = unicode(mes.title)
             text = date.decode('utf8') + "  " + title
 
-            #if not mes.read:
-                #text =text + "  <font color=\"green\">  NEW!!! </font>"
             author = mes.poster
             if author:
                 icon = author.get_icon()
@@ -95,7 +94,10 @@ class ListMyPosts(MainWindow):
             new_item = QtGui.QListWidgetItem(QtGui.QIcon(QtCore.QString(icon)),
                                              text,
                                              list_widget)
-            new_item.setData(1, QtCore.QVariant(index))
+            new_item.setData(QtCore.Qt.UserRole, QtCore.QVariant(index))
+            if not mes.read:
+                #new_item.setData(QtCore.Qt.DecorationRole, QtCore.QVariant(QtGui.QIcon(QtCore.QString("new.png"))))
+                new_item.setTextColor(QtGui.QColor(QtCore.Qt.green)) 
             index = index + 1
             del text
             del title
@@ -112,6 +114,8 @@ class ListMyPosts(MainWindow):
         file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         file_tool_bar.addWidget(self.refresh_act)
         file_tool_bar.addWidget(self.del_act)
+        if self.friend:
+            self.del_act.setDisabled(True)
         self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                              self.home_window)
         return file_tool_bar
@@ -146,9 +150,9 @@ class ListMyPosts(MainWindow):
         @param
         @return       
         """
-        index = item.data(1).toString().toInt()[0]
+        index = item.data(QtCore.Qt.UserRole).toString().toInt()[0]
         mes = self.list[index]
-        view_widg = ViewMessage(self, self.get_messages(), mes)
+        view_widg = ViewMessage(self, self.get_messages(self.friend), mes)
         
 
     def delete_message(self):
@@ -166,9 +170,8 @@ class ListMyPosts(MainWindow):
         list = self.mes_list.selectedItems()
         if list:
             for item in list:
-                index = item.data(1).toString().toInt()[0]
+                index = item.data(QtCore.Qt.UserRole).toString().toInt()[0]
                 mes = self.list[index]
-                
                 try:
                     mes.poster.del_post(mes)
                 except WarningExc, exc:
@@ -206,7 +209,7 @@ class ListMyPosts(MainWindow):
         """
         self.hbox.removeWidget(self.mes_list)
         self.mes_list.deleteLater()
-        self.mes_list = self.list_posts()
+        self.mes_list = self.list_posts(self.friend)
         self.hbox.addWidget(self.mes_list)
 
     def callback(self):
@@ -222,19 +225,32 @@ class ListMyPosts(MainWindow):
         """
         update list of messages from network
         """
-        list_acc = main_prof.accounts
-        for acc in list_acc:
-            try:
-                acc.refresh_posts(self.callback)
-            except WarningExc, exc:
-                main_window.show_warning(exc)
+        if not self.friend:
+            list_acc = main_prof.accounts
+            for acc in list_acc:
+                try:
+                    acc.refresh_posts(self.callback)
+                except WarningExc, exc:
+                    main_window.show_warning(exc)
+        else:
+            list_acc = main_prof.accounts
+            for acc in list_acc:
+                try:
+                    acc.refresh_friends_page(self.callback)
+                except WarningExc, exc:
+                    main_window.show_warning(exc)
 
 
-    def get_messages(self):
+
+
+    def get_messages(self, friend):
         """
         getting all messages
         """
-        return main_prof.get_posts()
+        if not friend:
+            return main_prof.get_posts()
+        else:
+            return friend.get_posts()
 
 class MyProgress(QtGui.QProgressDialog):
     """
