@@ -47,7 +47,8 @@ class StartPage(MainWindow):
 
         self.new_act.setDisabled(True)
         self.manage_act.setDisabled(True)
-
+        self.draft_act.setDisabled(True)
+        
         self.login_edit = QtGui.QLineEdit(self)
         self.pasw_edit = QtGui.QLineEdit(self)
         self.pasw_edit.setEchoMode(QtGui.QLineEdit.Password)
@@ -103,9 +104,11 @@ class StartPage(MainWindow):
         if self._add_new_account():
             self.new_act.setDisabled(False)
             self.manage_act.setDisabled(False)
+            self.draft_act.setDisabled(False)
+            
             self.hide()
             from HomePage import HomePage
-            home_page = HomePage()
+            home_page = HomePage(main_prof.def_account)
             self.parent = home_page
             super(StartPage, self).home_window()
             
