@@ -56,8 +56,8 @@ class ViewMessage(MainWindow):
         if key > len(self.list) - 2:
             self.down_act.setDisabled(True)
         #check out JS scripts
-        QWebSettings.globalSettings().setAttribute(QWebSettings.JavascriptEnabled,
-                                                   False)
+        #QWebSettings.globalSettings().setAttribute(QWebSettings.JavascriptEnabled,
+        #                                           False)
         #cache settings
         try:
             QWebSettings.globalSettings().setAttribute(QWebSettings.LocalStorageEnabled,
@@ -119,6 +119,8 @@ class ViewMessage(MainWindow):
             text = ""
         if not date:
             date = ""
+        if not msg.read:
+            msg.read = True
 
         import tidylib
         text = tidylib.tidy_fragment(text)[0]
